@@ -1,6 +1,5 @@
-import datetime
+
 from ast import literal_eval
-from multiprocessing import Process
 
 from cloud_governance.common.clouds.aws.ec2.ec2_operations import EC2Operations
 from cloud_governance.common.elasticsearch.elastic_upload import ElasticUpload
@@ -31,15 +30,7 @@ class CostExplorer:
         self.region = self.__environment_variables_dict.get('AWS_DEFAULT_REGION', 'us-east-1')
         self._ec2_operations = EC2Operations(region=self.region)
         self._elastic_upload = ElasticUpload()
-        self.__account = self.__environment_variables_dict.get('account')
-
-    def get_user_resources(self):
-        """
-        This method get User all region ec2 instances
-        @return:
-        """
-        ec2_global_list_user_resources = self._ec2_operations.get_global_ec2_list_by_user()
-        return ec2_global_list_user_resources
+        self.__account = self.__environment_variables_dict.get('account').upper().replace('OPENSHIFT-', "").strip()
 
     def filter_data_by_tag(self, groups: dict, tag: str):
         """
@@ -49,19 +40,16 @@ class CostExplorer:
         @return: converted into dict format
         """
         data = {}
-        user_resources = []
         start_time = groups.get('TimePeriod').get('Start')
         account = self.__account
-        if tag == 'User' and start_time in str(datetime.datetime.now()- datetime.timedelta(1)):
-            user_resources = self.get_user_resources()
         for group in groups.get('Groups'):
             name = ''
             amount = ''
             if group.get('Keys'):
-                name = group.get('Keys')[0].split('$')[-1]
+                name = group.get('Keys')[0].split('$')[-1].strip().replace(' ', '-')
                 if name == 'PERF-SCALE':
                     name = 'PERFSCALE'
-                name = name if name else f'{self._elastic_upload.account}-REFUND'
+                name = name if name else f'{self._elastic_upload.account}-REFUND/TAX/RECURRING_FEE'
             if group.get('Metrics'):
                 amount = group.get('Metrics').get(self.cost_metric).get('Amount')
             if name and amount:
@@ -72,9 +60,8 @@ class CostExplorer:
                         name = 'vm_import_image'
                 index_id = f'{start_time.lower()}-{account.lower()}-{tag.lower()}-{name.lower()}'
                 if index_id not in data:
-                    upload_data = {tag: name.upper(), 'Cost': round(float(amount), 3), 'index_id': index_id, 'timestamp': start_time}
-                    if user_resources and name in user_resources:
-                        upload_data['Instances'] = user_resources[name]
+                    upload_data = {tag: name if tag.upper() == 'ChargeType'.upper() else name.upper(),
+                                   'Cost': round(float(amount), 3), 'index_id': index_id, 'timestamp': start_time}
                     if 'global' in self._elastic_upload.es_index:
                         if 'Budget' not in upload_data:
                             upload_data['Budget'] = self._elastic_upload.account
@@ -114,16 +101,9 @@ class CostExplorer:
                 for value in data:
                     file.write(f'{value}\n')
         else:
-            pass
-            for bulk in range(0, len(data), self.BULK_UPLOAD_THREADS):
-                jobs = []
-                for value in data[bulk: bulk+self.BULK_UPLOAD_THREADS]:
-                    p = Process(target=self.upload_item_to_es, args=(value, index, value['index_id'], ))
-                    p.start()
-                    jobs.append(p)
-                for job in jobs:
-                    job.join()
-        logger.info(f'Data uploaded to {index}, Total Data: {len(data)}')
+            for value in data:
+                self.upload_item_to_es(index=index, item=value, index_id=value['index_id'])
+            logger.info(f'Data uploaded to {index}, Total Data: {len(data)}')
 
     def upload_item_to_es(self, item: dict, index: str, index_id: str = ''):
         """
